==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/loader/impl/UniqueIDSerializerSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeSerializerSet;
import io.ciera.tool.sql.loader.UniqueIDSerializer;
import io.ciera.tool.sql.loader.UniqueIDSerializerSet;
import io.ciera.tool.sql.loader.impl.AttributeSerializerSetImpl;

import java.util.Arrays;
import java.util.List;


public class UniqueIDSerializerSetImpl extends InstanceSet<UniqueIDSerializerSet,UniqueIDSerializer> implements UniqueIDSerializerSet {

    // attributes
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setLoader_name( ref_loader_name );
    }
    @Override
    public void setPrimary_key( boolean m_primary_key ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setPrimary_key( m_primary_key );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setAttr_name( ref_attr_name );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setClass_name( ref_class_name );
    }
    @Override
    public void setValue( String m_value ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setValue( m_value );
    }
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setLoader_package( ref_loader_package );
    }


    // selections
    @Override
    public AttributeSerializerSet R3004_is_a_AttributeSerializer() throws XtumlException {
        AttributeSerializerSet attributeserializerset = new AttributeSerializerSetImpl();
        for ( UniqueIDSerializer uniqueidserializer : this ) attributeserializerset.add( uniqueidserializer.R3004_is_a_AttributeSerializer() );
        return attributeserializerset;
    }


    @Override
    public UniqueIDSerializer nullElement() {
        return UniqueIDSerializerImpl.EMPTY_UNIQUEIDSERIALIZER;
    }

    @Override
    public UniqueIDSerializerSet emptySet() {
      return new UniqueIDSerializerSetImpl();
    }

    @Override
    public UniqueIDSerializerSet value() {
        return this;
    }

    @Override
    public List<UniqueIDSerializer> elements() {
        return Arrays.asList(toArray(new UniqueIDSerializer[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/loader/impl/UniqueIDSerializerSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeSerializerSet;
import io.ciera.tool.sql.loader.UniqueIDSerializer;
import io.ciera.tool.sql.loader.UniqueIDSerializerSet;
import io.ciera.tool.sql.loader.impl.AttributeSerializerSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class UniqueIDSerializerSetImpl extends InstanceSet<UniqueIDSerializerSet,UniqueIDSerializer> implements UniqueIDSerializerSet {

    public UniqueIDSerializerSetImpl() {
    }

    public UniqueIDSerializerSetImpl(Comparator<? super UniqueIDSerializer> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setLoader_package( ref_loader_package );
    }
    @Override
    public void setValue( String m_value ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setValue( m_value );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setClass_name( ref_class_name );
    }
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setLoader_name( ref_loader_name );
    }
    @Override
    public void setPrimary_key( boolean m_primary_key ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setPrimary_key( m_primary_key );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( UniqueIDSerializer uniqueidserializer : this ) uniqueidserializer.setAttr_name( ref_attr_name );
    }


    // selections
    @Override
    public AttributeSerializerSet R3004_is_a_AttributeSerializer() throws XtumlException {
        AttributeSerializerSet attributeserializerset = new AttributeSerializerSetImpl();
        for ( UniqueIDSerializer uniqueidserializer : this ) attributeserializerset.add( uniqueidserializer.R3004_is_a_AttributeSerializer() );
        return attributeserializerset;
    }


    @Override
    public UniqueIDSerializer nullElement() {
        return UniqueIDSerializerImpl.EMPTY_UNIQUEIDSERIALIZER;
    }

    @Override
    public UniqueIDSerializerSet emptySet() {
      return new UniqueIDSerializerSetImpl();
    }

    @Override
    public UniqueIDSerializerSet emptySet(Comparator<? super UniqueIDSerializer> comp) {
      return new UniqueIDSerializerSetImpl(comp);
    }

    @Override
    public UniqueIDSerializerSet value() {
        return this;
    }

    @Override
    public List<UniqueIDSerializer> elements() {
        return Arrays.asList(toArray(new UniqueIDSerializer[0]));
    }

}
